Package: vegan
Title: Community Ecology Package
Version: 2.7-5
Authors@R: c(person("Jari", "Oksanen", role=c("aut","cre"),
                    email="jhoksane@gmail.com",
		    comment = c(ORCID="0000-0001-7102-9626")),
	   person("Gavin L.", "Simpson", role="aut",
	            email="ucfagls@gmail.com",
		    comment = c(ORCID = "0000-0002-9084-8413")),
	   person("F. Guillaume", "Blanchet", role="aut"),
	   person("Roeland", "Kindt", role="aut"),
	   person("Pierre", "Legendre", role="aut"),
	   person("Peter R.", "Minchin", role="aut"),
	   person("R.B.", "O'Hara", role="aut"),
	   person("Peter", "Solymos", role="aut"),
	   person("M. Henry H.", "Stevens", role="aut"),
	   person("Eduard", "Szoecs", role="aut"),
	   person("Helene", "Wagner", role="aut"),
	   person("Matt", "Barbour", role="ctb"),
	   person("Michael", "Bedward", role="aut"),
	   person("Henrik", "Bengtsson", role="ctb"),
	   person("Ben", "Bolker", role="aut"),
	   person("Daniel", "Borcard", role="aut"),
	   person("Tuomas", "Borman", role="ctb"),
	   person("Gustavo", "Carvalho", role="aut"),
	   person("Michael", "Chirico", role="ctb"),
	   person("Miquel", "De Caceres", role="aut"),
	   person("Sebastien", "Durand", role="aut"),
	   person("Heloisa Beatriz Antoniazi", "Evangelista", role="aut"),
	   person("Rich", "FitzJohn", role="ctb"),
	   person("Michael", "Friendly", role="ctb"),
	   person("Brendan","Furneaux", role="ctb"),
	   person("Geoffrey", "Hannigan", role="aut"),
	   person("Isaac", "Heida", role="ctb"),
	   person("Mark O.", "Hill", role="aut"),
	   person("Leo", "Lahti", role="aut"),
	   person("Cameron", "Martino", role="aut"),
	   person("Dan", "McGlinn", role="ctb"),
	   person("Marie-Helene", "Ouellette", role="aut"),
	   person("Eduardo", "Ribeiro Cunha", role="aut"),
	   person("Tyler", "Smith", role="aut"),
	   person("Adrian", "Stier", role="aut"),
	   person("Cajo J.F.", "Ter Braak", role="aut"),
	   person("James", "Weedon", role="aut"))
Depends: permute (>= 0.9-0), R (>= 4.1.0)
Suggests: parallel, knitr, markdown
Imports: MASS, cluster, lattice, mgcv
VignetteBuilder: utils, knitr
Description: Ordination methods, diversity analysis and other
  functions for community and vegetation ecologists.
License: GPL-2
BugReports: https://github.com/vegandevs/vegan/issues
URL: https://vegandevs.github.io/vegan/,
        https://github.com/vegandevs/vegan
NeedsCompilation: yes
Packaged: 2026-05-25 14:59:23 UTC; jarioksa
Author: Jari Oksanen [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7102-9626>),
  Gavin L. Simpson [aut] (ORCID: <https://orcid.org/0000-0002-9084-8413>),
  F. Guillaume Blanchet [aut],
  Roeland Kindt [aut],
  Pierre Legendre [aut],
  Peter R. Minchin [aut],
  R.B. O'Hara [aut],
  Peter Solymos [aut],
  M. Henry H. Stevens [aut],
  Eduard Szoecs [aut],
  Helene Wagner [aut],
  Matt Barbour [ctb],
  Michael Bedward [aut],
  Henrik Bengtsson [ctb],
  Ben Bolker [aut],
  Daniel Borcard [aut],
  Tuomas Borman [ctb],
  Gustavo Carvalho [aut],
  Michael Chirico [ctb],
  Miquel De Caceres [aut],
  Sebastien Durand [aut],
  Heloisa Beatriz Antoniazi Evangelista [aut],
  Rich FitzJohn [ctb],
  Michael Friendly [ctb],
  Brendan Furneaux [ctb],
  Geoffrey Hannigan [aut],
  Isaac Heida [ctb],
  Mark O. Hill [aut],
  Leo Lahti [aut],
  Cameron Martino [aut],
  Dan McGlinn [ctb],
  Marie-Helene Ouellette [aut],
  Eduardo Ribeiro Cunha [aut],
  Tyler Smith [aut],
  Adrian Stier [aut],
  Cajo J.F. Ter Braak [aut],
  James Weedon [aut]
Maintainer: Jari Oksanen <jhoksane@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-25 16:50:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-05-25 18:23:46 UTC; unix
Archs: vegan.so.dSYM
