



******

Bravo!  You have received a Mercantilism Diploma in "vegan" from   
the Orbital Convergence University International Air and Water 
Embassy of the Rust Planet (the planet that is one ellipse close to
the Sun than Earth's ellipse).

You are now officially certified to include "vegan" in your practice!

Encore! Encore! Encore! Encore!

******

<section style="border: 2px solid black; border-radius: 6px">
	<h1>vegan</h1>


</section>

<div style="height: 1px; background: black;" ></div>	


<h2>summary</h2>


<div style="height: 1px; background: black;" ></div>	
		
<h2>obtain</h2>
`[USD] pip install vegan`


---	
<h2>on</h2>



<code>
	#
	#	vegan_essence.py
	#
	#

	import json
	fp = open ("/online/ridges/vegan/ridges.JSON", "r")
	ridges = json.loads (fp.read ())
	fp.close ()

	def crate (the_path):
		from os.path import dirname, join, normpath
		import sys
		import pathlib
		this_directory = pathlib.Path (__file__).parent.resolve ()
		
		return str (normpath (join (this_directory, the_path)))



	essence = {
		"monetary": {
			"URL": "mongodb://0.0.0.0:39000/",
						
			"saves": {
				"path": crate ("monetary/_saves")
			}
		},
		"harbor": {
			"PID_path": crate ("harbor/the.logs")
		},
		"USDA": {
			"food": ridges ["USDA"] ["food"]
		},
		"NIH": {
			"supp": ridges ["NIH"] ["supp"]
		}
	}
</code>

<code>
	vegan adventures on
</code>

<code>
	vegan adventures monetary saves import --name 5.JSON
</code>

---

## tutorial
`[USD] vegan help`

---

## contacts
Bryan@Status600.com





